@@ -1,8 +1,11 @@
 from django.utils import simplejson
-from django.http import HttpResponse
+
 
 def flash_context(request):
-    flash = None
+    flash = request.flash
+    if flash:
+        request.flash = {}
+
     if 'flashcookie' in request.COOKIES:
         try:
             flash = simplejson.loads(request.COOKIES['flashcookie'])
