@@ -38,5 +38,8 @@ class FlashMiddleware(object):
         if hasattr(request, 'flash') and len(request.flash):
             self._set_messages(request, response)
         else:
-            response.delete_cookie('flashcookie')
+            try:
+                response.delete_cookie('flashcookie')
+            except AttributeError:
+                pass
         return response
